mod crypto_aead_chacha20poly1305;
mod crypto_auth;
mod crypto_auth_hmacsha256;
mod crypto_auth_hmacsha512;
mod crypto_auth_hmacsha512256;
mod crypto_box;
mod crypto_box_curve25519xsalsa20poly1305;
mod crypto_core_hsalsa20;
mod crypto_core_salsa20;
mod crypto_core_salsa2012;
mod crypto_core_salsa208;
mod crypto_generichash;
mod crypto_generichash_blake2b;
mod crypto_hash;
mod crypto_hash_sha256;
mod crypto_hash_sha512;
mod crypto_kx;
mod crypto_onetimeauth;
mod crypto_onetimeauth_poly1305;
mod crypto_pwhash_scryptsalsa208sha256;
mod crypto_scalarmult;
mod crypto_scalarmult_curve25519;
mod crypto_secretbox;
mod crypto_secretbox_xsalsa20poly1305;
mod crypto_shorthash_siphash24;
mod crypto_sign_ed25519;
mod crypto_stream;
mod crypto_stream_chacha20;
mod crypto_stream_salsa20;
mod crypto_stream_salsa2012;
mod crypto_stream_salsa208;
mod crypto_stream_xchacha20;
mod crypto_stream_xsalsa20;
mod crypto_verify_16;
mod crypto_verify_32;
mod crypto_verify_64;
